DeviceOTACore class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enableOTAAutoUpgrade(String serialNumber, bool enable, {required void onSuccess(int code, String msg), required OnError onError}) → void
getDeviceOtaDetail(String serialNumber, {required OnSuccess<OtaBean> onSuccess, required OnError onError}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
otaStart(String serialNumber, {required void onSuccess(int code, String msg), required OnError onError, required OnOtaProgress onProgress}) → void
stopOTA() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getInstance() DeviceOTACore?