LibraryCore class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeP2PConnection(String serialNumber, {required OnSuccess<String?> onSuccess, required OnError onError}) → void
deleteRecord(List<String> traceIds, {required OnSuccess<String> onSuccess, required OnError onError}) → void
downloadSource(List<RecordEventDetailBean?> tasks, bool isShare, {double? speedRatio, required OnProgress onProgress, required OnFinish onFinish}) → void
speedRatio 变速下载(慢动作导出):取值 1 / 0.5 / 0.25 / 0.125, null 或 1 按原速。非 1x 输出不保留音轨(双端原生 SDK 行为)。 双端均支持:iOS 走 SDK ts2Mp4 转码参数,Android 写入每个任务的 RecordBean.downloadSpeed 后由原生下载控制器转码。
getEventDetail(bool isFromSDCard, String? videoEventKey, {required OnSuccess<LibraryEventDetailBean> onSuccess, required OnError onError}) → void
getEventRecordByFilter(FilterEntry filterEntry, {required OnSuccess<LibraryEventDatabean> onSuccess, required OnError onError}) → void
getLibraryByTraceId(String traceId, {required OnSuccess<RecordEventDetailBean> onSuccess, required OnError onError}) → void
getLibraryStatus(FilterEntry filterEntry, {required OnSuccess<LibraryStatusDatabean> onSuccess, required OnError onError}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openP2PConnection(String serialNumber, {required OnSuccess<String?> onSuccess, required OnError onError}) → void
queryUserActivityZone({required OnSuccess<AllZoneBean> onSuccess, required OnError onError}) → void
queryVideoSearchOption(bool isFromSDCard, String? serialNumber, {required OnSuccess<TagBean?> onSuccess, required OnError onError}) → void
setMarkStatus(int marked, String? traceIds, {required OnSuccess<String> onSuccess, required OnError onError}) → void
setReadStatus(int missing, String? traceIds, {required OnSuccess<String> onSuccess, required OnError onError}) → void
stopDownload() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getInstance() LibraryCore?