DownloadResultListener class

Constructors

DownloadResultListener({required OnProgress onProgress, required OnFinish onFinish})

Properties

hashCode int
The hash code for this object.
no setterinherited
nativeType String
getter/setter pair
onFinish OnFinish
final
onProgress OnProgress
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String methodName, List data) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited