FilterEntry class

Annotations
  • @JsonSerializable.new()

Constructors

FilterEntry()
FilterEntry.fromJson(Map<String, dynamic> json)
factory

Properties

deviceCallEventTag String?
getter/setter pair
deviceName String?
getter/setter pair
doorbellTags List<String>?
getter/setter pair
endTimestamp int
getter/setter pair
from int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isFromSDCard bool
getter/setter pair
marked int
getter/setter pair
missing int
getter/setter pair
nativeType → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumbers List<String>?
getter/setter pair
serialNumberToActivityZone Map<String, List<int>>?
getter/setter pair
startTimestamp int
getter/setter pair
tags List<String>?
getter/setter pair
to int
getter/setter pair
videoEventKey String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited