TagBean class

Annotations
  • @JsonSerializable.new()

Constructors

TagBean()
TagBean.fromJson(Map<String, dynamic> json)
factory

Properties

aiEventTags List<OptionTag>?
getter/setter pair
deviceEventTags List<OptionTag>?
getter/setter pair
devices List<OptionDevice>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
operateOptions List<OptionTag>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited