NatureChatStreamCallback class

/message SSE 流式回调。onContent/onSuggestions 可多次(非终态),onDone/onError 终态。

Constructors

NatureChatStreamCallback({required void onContent(String text), required void onSuggestions(List<String> suggestions), required void onDone(), required void onError(String? code, String? message)})

Properties

hashCode int
The hash code for this object.
no setterinherited
nativeType String
getter/setter pair
onContent → void Function(String text)
final
onDone → void Function()
final
onError → void Function(String? code, String? message)
final
onSuggestions → void Function(List<String> suggestions)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String methodName, List data) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() List<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited