OtaBean class

Annotations
  • @JsonSerializable.new()

Constructors

OtaBean({String? serialNumber, int statusCode = 0, String? currentFirmware, String? targetFirmware, int firmwareStatus = 0, int size = 0, String? md5, String? modelNo, int adminId = 0, String? newestFirmwareId, bool encrypted = false, List<String>? releaseNote})
OtaBean.fromJson(Map<String, dynamic> json)
factory

Properties

adminId int
getter/setter pair
currentFirmware String?
getter/setter pair
encrypted bool
getter/setter pair
firmwareStatus int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
md5 String?
getter/setter pair
modelNo String?
getter/setter pair
newestFirmwareId String?
getter/setter pair
releaseNote List<String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
getter/setter pair
size int
getter/setter pair
statusCode int
getter/setter pair
targetFirmware String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited