VideoResolution enum
Values
- VIDEO_SIZE_AUTO → const VideoResolution
- VIDEO_SIZE_640x360 → const VideoResolution
- VIDEO_SIZE_640x480 → const VideoResolution
- VIDEO_SIZE_960x720 → const VideoResolution
- VIDEO_SIZE_1280x720 → const VideoResolution
- VIDEO_SIZE_1280x960 → const VideoResolution
- VIDEO_SIZE_1920x1080 → const VideoResolution
- VIDEO_SIZE_2048x1440 → const VideoResolution
- VIDEO_SIZE_2048x1536 → const VideoResolution
- VIDEO_SIZE_2304x1296 → const VideoResolution
- VIDEO_SIZE_2560x1440 → const VideoResolution
- VIDEO_SIZE_3840x2160 → const VideoResolution
- VIDEO_SIZE_7680x4320 → const VideoResolution
- VIDEO_SIZE_1280x720_60 → const VideoResolution
-
高帧率(慢动作)档位,值为
<宽>x<高>@<fps>。 设备是否支持见DeviceSupport.supportHighFramerateResolution; 直播中切换高帧率档位当前双端原生 SDK 均未开放,此类值用于DeviceSettingCore.updateAttribute(sn, 'videoResolution', value)。 - VIDEO_SIZE_1024x768_60 → const VideoResolution
- VIDEO_SIZE_1920x1080_120 → const VideoResolution
- VIDEO_SIZE_2000x1500_120 → const VideoResolution
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoResolution> - A constant List of the values in this enum, in order of their declaration.