DeviceSettingCore class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAttribute(String serialNumber, {required OnSuccess<DeviceAttributesBean> onSuccess, required OnError onError})
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setMotionTrack(String serialNumber, bool enable, {required OnSuccess onSuccess, required OnError onError})
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateAttribute(String serialNumber, String name, Object value, {required OnSuccess onSuccess, required OnError onError})
→ void
-
通用设备属性更新,对应原生
updateAttribute(serialNumber, name, value)。
典型用法:开启高帧率(慢动作)档位
updateAttribute(sn, 'videoResolution', '1280x720@60', ...);
可选档位来自 DeviceBean.deviceSupport.supportHighFramerateResolution。
注意:设备开启高帧率后会关闭 HDR/WDR(原生 App 的产品规则),
需要时由接入方自行提示用户。