RecordEventBean class
- Annotations
-
- @JsonSerializable.new()
Constructors
- RecordEventBean()
-
RecordEventBean.fromJson(Map<
String, dynamic> json) -
factory
Properties
- adminId ↔ int
-
getter/setter pair
- deviceName ↔ String?
-
getter/setter pair
- endTime ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPossibleSubcategory ↔ bool?
-
getter/setter pair
- imageUrl ↔ String?
-
getter/setter pair
- libraryCount ↔ int?
-
getter/setter pair
- marked ↔ int
-
getter/setter pair
- missing ↔ int
-
getter/setter pair
- period ↔ double?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serialNumber ↔ String?
-
getter/setter pair
- startTime ↔ int?
-
getter/setter pair
- supportMagicPix ↔ bool?
-
getter/setter pair
-
getter/setter pair
- traceIds ↔ String?
-
getter/setter pair
- type ↔ int?
-
getter/setter pair
- videoEventKey ↔ String?
-
getter/setter pair
- videoUrl ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited