NatureChatMessageRequest class
Constructors
Properties
- adminUserId ↔ String?
-
共享设备主人 userId,继承会员用。
getter/setter pair
- birdImage ↔ String?
-
getter/setter pair
- birdName ↔ String?
-
getter/setter pair
- birdScientificName ↔ String?
-
getter/setter pair
- birdStory ↔ String?
-
getter/setter pair
- content ↔ String
-
用户问题原文。必填。
getter/setter pair
- functionType ↔ String?
-
功能类型,默认 "chat"(后端当前不用,预留)。
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- language ↔ String?
-
getter/setter pair
- metadata ↔ String?
-
附加元数据(JSON 字符串),透传给 agent。
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId ↔ String
-
客户端生成的会话 UUID,每会话一个,整段复用。必填。
getter/setter pair
- tenantId ↔ String?
-
getter/setter pair
- timezone ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited