OtaCallback class
Constructors
- OtaCallback({required void onSuccess(int code, String msg), required void onError(int code, String msg), required OnOtaProgress onProgress})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativeType ↔ String
-
getter/setter pair
- onError → void Function(int code, String msg)
-
final
- onProgress → OnOtaProgress
-
final
- onSuccess → void Function(int code, String msg)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
String methodName, List data) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → List< String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited